@@ -238,7 +238,7 @@ for (var i = 0; i < 4; i++) ucnew[i] =  new JU.P3 ();
 
 JU.SimpleUnitCell.setOabc (s, null, ucnew);
 } else if (s.indexOf (",") >= 0) {
-return mp.addXObj (this.vwr.getV0abc (s));
+return mp.addXObj (this.vwr.getV0abc (-1, s));
 }break;
 }
 var u = null;
@@ -460,19 +460,15 @@ var sOpt = JS.SV.sValue (args[args.length - 1]);
 var isStdDev = sOpt.equalsIgnoreCase ("stddev");
 var isIsomer = sOpt.equalsIgnoreCase ("ISOMER");
 var isBonds = sOpt.equalsIgnoreCase ("BONDS");
-var isSmiles = (!isIsomer && args.length > (isStdDev ? 3 : 2));
+var isPoints = (args[0].tok == 7 && args[1].tok == 7);
+var isSmiles = (!isPoints && !isIsomer && args.length > (isStdDev ? 3 : 2));
 var bs1 = (args[0].tok == 10 ? args[0].value : null);
 var bs2 = (args[1].tok == 10 ? args[1].value : null);
 var smiles1 = (bs1 == null ? JS.SV.sValue (args[0]) : "");
 var smiles2 = (bs2 == null ? JS.SV.sValue (args[1]) : "");
-var m =  new JU.M4 ();
 stddev = NaN;
-var ptsA;
-var ptsB;
 try {
-if (isSmiles) {
-if (bs1 == null || bs2 == null) return false;
-}if (isBonds) {
+if (isBonds) {
 if (args.length != 4) return false;
 smiles1 = JS.SV.sValue (args[2]);
 isSmiles = smiles1.equalsIgnoreCase ("SMILES");
@@ -521,23 +517,29 @@ check = ((ret).nextSetBit (0) >= 0);
 }if (bs1 == null || bs2 == null) return mp.addXStr ("IDENTICAL");
 stddev = this.e.getSmilesExt ().getSmilesCorrelation (bs1, bs2, smiles1, null, null, null, null, false, null, null, false, 1);
 return mp.addXStr (stddev < 0.2 ? "IDENTICAL" : "IDENTICAL or CONFORMATIONAL ISOMERS (RMSD=" + stddev + ")");
-}if (isSmiles) {
-ptsA =  new JU.Lst ();
-ptsB =  new JU.Lst ();
+}var m =  new JU.M4 ();
+var ptsA = null;
+var ptsB = null;
+if (isSmiles) {
+if (bs1 == null || bs2 == null) return false;
 sOpt = JS.SV.sValue (args[2]);
 var isMap = sOpt.equalsIgnoreCase ("MAP");
 isSmiles = sOpt.equalsIgnoreCase ("SMILES");
 var isSearch = (isMap || sOpt.equalsIgnoreCase ("SMARTS"));
 if (isSmiles || isSearch) sOpt = (args.length > (isStdDev ? 4 : 3) ? JS.SV.sValue (args[3]) : null);
 var hMaps = (("H".equalsIgnoreCase (sOpt) || "allH".equalsIgnoreCase (sOpt) || "bestH".equalsIgnoreCase (sOpt)));
-var isPolyhedron = ("polyhedra".equalsIgnoreCase (sOpt));
-if (isPolyhedron) sOpt = (args.length > (isStdDev ? 5 : 4) ? JS.SV.sValue (args[4]) : null);
+var isPolyhedron = !hMaps && ("polyhedra".equalsIgnoreCase (sOpt) || "polyhedron".equalsIgnoreCase (sOpt));
+if (isPolyhedron) {
+stddev = this.e.getSmilesExt ().mapPolyhedra (bs1.nextSetBit (0), bs2.nextSetBit (0), isSmiles, m);
+} else {
+ptsA =  new JU.Lst ();
+ptsB =  new JU.Lst ();
 var allMaps = (("all".equalsIgnoreCase (sOpt) || "allH".equalsIgnoreCase (sOpt)));
 var bestMap = (("best".equalsIgnoreCase (sOpt) || "bestH".equalsIgnoreCase (sOpt)));
 if ("stddev".equals (sOpt)) sOpt = null;
 var pattern = sOpt;
 if (sOpt == null || hMaps || allMaps || bestMap) {
-if (!isMap && !isSmiles || hMaps && isPolyhedron) return false;
+if (!isMap && !isSmiles || hMaps) return false;
 pattern = "/noaromatic" + (allMaps || bestMap ? "/" : " nostereo/") + this.e.getSmilesExt ().getSmilesMatches ((hMaps ? "H" : ""), null, bs1, null, 1, true, false);
 } else {
 allMaps = true;
@@ -554,8 +556,20 @@ for (var j = 0; j < nAtoms; j++, pt++) a[j] =  Clazz.newIntArray (-1, [(ptsA.get
 
 }
 return (allMaps ? mp.addXList (ret) : ret.size () > 0 ? mp.addXAII (ret.get (0)) : mp.addXStr (""));
-}} else {
-switch (args.length) {
+}}}if (isPoints) {
+ptsA = this.e.getPointVector (args[0], 3);
+ptsB = this.e.getPointVector (args[1], 3);
+var a = (args.length >= 3 ? args[2].getList () : null);
+var na = args.length;
+if (a != null) {
+na--;
+var n = a.size ();
+if (n != ptsA.size () || n != ptsB.size ()) return false;
+var list =  new JU.Lst ();
+for (var i = 0; i < n; i++) list.addLast (ptsA.get (a.get (i).intValue));
+
+ptsA = list;
+}switch (na) {
 case 2:
 break;
 case 3:
@@ -563,9 +577,7 @@ if (isStdDev) break;
 default:
 return false;
 }
-ptsA = this.e.getPointVector (args[0], 0);
-ptsB = this.e.getPointVector (args[1], 0);
-if (ptsA != null && ptsB != null) {
+if (ptsA != null && ptsB != null && ptsA.size () == ptsB.size ()) {
 J.api.Interface.getInterface ("JU.Eigen", this.vwr, "script");
 stddev = JU.Measure.getTransformMatrix4 (ptsA, ptsB, m, null);
 }}return (isStdDev || Float.isNaN (stddev) ? mp.addXFloat (stddev) : mp.addXM4 (m.round (1e-7)));
@@ -2306,7 +2318,7 @@ var nth = (pt2 != null && args.length > apt && iOp == -2147483648 && args[apt].t
 if (nth >= 0) apt++;
 if (iOp == -2147483648) iOp = 0;
 var desc = (narg == apt ? (pt2 != null ? "all" : pt1 != null ? "point" : "matrix") : JS.SV.sValue (args[apt++]).toLowerCase ());
-return (bsAtoms != null && !bsAtoms.isEmpty () && apt == args.length && mp.addXObj (this.vwr.getSymmetryInfo (bsAtoms.nextSetBit (0), xyz, iOp, trans, pt1, pt2, 0, desc, 0, nth, 0)));
+return (bsAtoms != null && !bsAtoms.isEmpty () && apt == args.length && mp.addXObj (this.vwr.getSymmetryInfo (bsAtoms.nextSetBit (0), xyz, iOp, trans, pt1, pt2, 1275068418, desc, 0, nth, 0)));
 }, "JS.ScriptMathProcessor,~A,~B");
 Clazz.defineMethod (c$, "evaluateTensor", 
  function (mp, args) {
